@@ -1155,6 +1155,11 @@ static void setup_config_dir(void)
     symlink( "../drive_c", "dosdevices/c:" );
 #ifndef __ANDROID__
     symlink( "/", "dosdevices/z:" );
+#else
+    mkdir( "drive_c/windows", 0777 );
+    mkdir( "drive_c/windows/Fonts", 0777 );
+    symlink( "/system/fonts", "drive_c/windows/Fonts/systemfonts" );
+    symlink( "../../../../../share/wine/fonts", "drive_c/windows/Fonts/sharefonts" );
 #endif
 }
 
